---
title: "😊 Welcome to ART"
sidebarTitle: "😊 Welcome to ART!"
description: "
Greetings fellow artisans!"
---

ART makes it easy to train agents for many different tasks.

<CardGroup cols={2}>
  <Card title="Get Started" icon="code" href="/getting-started/quick-start">
    Quickly integrate the OpenPipe SDK into your application and start
    collecting data.
  </Card>
  <Card title="Features" icon="lightbulb" href="/overview#what-we-provide">
    View the platform features OpenPipe provides and learn how to use them.
  </Card>
  <Card
    title="Sample Project"
    icon="vial"
    href="https://app.openpipe.ai/p/BRZFEx50Pf/request-logs"
  >
    Glance over the public demo we've set up to get an idea for how OpenPipe
    works.
  </Card>
</CardGroup>
